package com.huifu.example.acou;

import com.alibaba.fastjson.JSON;
import com.huifu.hfpay.master.domain.CfcaInfoBo;
import com.huifu.hfpay.master.util.constant.Constants;
import com.huifu.hfpay.master.util.security.SecurityService;
import jodd.http.HttpRequest;
import jodd.http.HttpResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.Map;

/**
 * @author zhiwei.cai
 * @version V1.0
 * @Title: hfpay-demo
 * @Package com.huifu.example.acou
 * @Description: 企业开户
 * @date 2019/8/15
 */
@Controller
@RequestMapping(value = "/")
public class Corp01 {
    public static Logger log = LoggerFactory.getLogger(Corp01.class);

    //商户客户号
    private static final String merCustId="6666000000002619";
    //身份证
    private static final String idCard="110101199003079876";
    //企业开户请求地址
    private static final String payUrl="https://hfpay.testpnr.com/api/acou/corp01";
    //加签证书地址
    private static final String pfxFile="/app/etc/product/888888-NEW.pfx";
    //加签证书秘钥
    private static final String pfxFilePwd="123456";
    //解签证书地址
    private static final String cerFile="/app/etc/product/CFCA_ACS_TEST_OCA31.cer";
    //手机号
    private static final String userMobile="13111111111";
    //解签证书所属商户号
    private static final String hfMerId="100001";

    /**
     * 企业开户
     * @param map
     * @param request
     * @param response
     * @param session
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/corp01")
    @ResponseBody
    public String bind(ModelMap map, HttpServletRequest request,
                      HttpServletResponse response, HttpSession session) throws Exception {
        //组装支付+请求参数
        Map<String, String> payParams = new HashMap<String, String>();
        payParams.put(Constants.VERSION, Constants.VERSION_VALUE);
        payParams.put(Constants.MER_CUST_ID, merCustId);
        payParams.put(Constants.ORDER_ID, makeOrderId());
        SimpleDateFormat dateformat = new SimpleDateFormat("yyyyMMdd");
        String dateStr = dateformat.format(System.currentTimeMillis());
        payParams.put(Constants.ORDER_DATE, dateStr);
        payParams.put(Constants.OPERATE_TYPE, "A");
        payParams.put(Constants.APPLY_ID, "1231234");

        payParams.put(Constants.CORP_LICENSE_TYPE, "2");
        payParams.put(Constants.LICENSE_START_DATE, "20190816");
        payParams.put(Constants.LICENSE_END_DATE, "20220101");
        payParams.put(Constants.CORP_NAME, "企业开户名字");
        payParams.put(Constants.CORP_BUSINESS_ADDRESS, "企业经营地址");
        payParams.put(Constants.CORP_REG_ADDRESS, "企业注册地址");
        payParams.put(Constants.CORP_FIXED_TELEPHONE, "88885554");
        payParams.put(Constants.BUSINESS_SCOPE, "1234567");
        payParams.put(Constants.BANK_ID, "00000012");

    //    payParams.put(Constants.CONTROLLING_SHAREHOLDER, "[{\"custName\":\"关羽\",\"idCardType\":\"10\",\"idCard\":\"330204199008187881，ratio\":\"50\"，shareholderAddr\":\"上海市\"}]");

        payParams.put(Constants.LEGAL_NAME, "法人名字");
        payParams.put(Constants.LEGAL_ID_CARD_TYPE, "10");
        payParams.put(Constants.LEGAL_ID_CARD, idCard);
        payParams.put(Constants.LEGAL_MOBILE, userMobile);
        payParams.put(Constants.CONTACT_NAME, "联系人");
        payParams.put(Constants.CONTACT_MOBILE, "13222222222");
        payParams.put(Constants.CONTACT_EMAIL, "user@qq.com");

        payParams.put(Constants.LEGAL_CERT_START_DATE, "20190816");
        payParams.put(Constants.LEGAL_CERT_END_DATE, "20220101");

        payParams.put(Constants.BANK_ACCT_NUM, "622840201704116183");
        payParams.put(Constants.BANK_ACCT_NAME, "账户名称");
        payParams.put(Constants.BANK_BRANCH, "银行分行名称");
        payParams.put(Constants.BANK_PROV, "0031");
        payParams.put(Constants.BANK_AREA, "3100");

        payParams.put(Constants.ATTACH_NOS, "31231331,123131,123123");

        payParams.put(Constants.BG_RET_URL, "http://rencai.com");

        payParams.put(Constants.MER_PRIV, "");
        payParams.put(Constants.EXTENSION, "");

        CfcaInfoBo cfcaInfoBo = new CfcaInfoBo();
        // 解签证书
        cfcaInfoBo.setCerFile(cerFile);
        // 加签证书
        cfcaInfoBo.setPfxFile(pfxFile);
        // 加签密码
        cfcaInfoBo.setPfxFilePwd(pfxFilePwd);
        // 商户ID
        cfcaInfoBo.setNpayMerId(hfMerId);

        // 转换成json格式
        String paramsStr = JSON.toJSONString(payParams);
        log.info("企业开户请求参数："+paramsStr);
        // 加签
        String sign = SecurityService.sign(paramsStr,cfcaInfoBo);
        HttpRequest httpRequest = HttpRequest.post(payUrl).charset("UTF-8");
        // 组织post数据
        String postStr = "version=" + Constants.VERSION_VALUE
                + "&mer_cust_id=" + merCustId
                + "&check_value=" + sign;

        // 发送请求给汇付
        HttpResponse httpResponse = httpRequest
                .contentType("application/x-www-form-urlencoded").body(postStr)
                .send();
        // 取得同步返回数据
        String body = httpResponse.bodyText();
        // 进行验签
        String resultStr = SecurityService.parseCVResult(body,cfcaInfoBo);
        log.info("企业开户返回参数："+resultStr);
        return resultStr;
    }

    /**
     * 生成订单号
     * @return
     */
    private String makeOrderId(){
        return "TEST"+System.currentTimeMillis();
    }
}
