package com.huifu.example.acou;

import com.alibaba.fastjson.JSON;
import com.huifu.hfpay.master.domain.CfcaInfoBo;
import com.huifu.hfpay.master.util.constant.Constants;
import com.huifu.hfpay.master.util.security.SecurityService;
import jodd.http.HttpRequest;
import jodd.http.HttpResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.Map;

/**
 * @author zhiwei.cai
 * @version V1.0
 * @Title: hfpay-demo
 * @Package com.huifu.example.acou
 * @Description: 转账
 * @date 2019/8/15
 */
@Controller
@RequestMapping(value = "/")
public class Trac01 {
    public static Logger log = LoggerFactory.getLogger(Trac01.class);

    //商户客户号
    private static final String merCustId="6666000000002619";
    private static final String outCustId ="6666000000066188";
    private static final String inCustId ="6666000000066187";
    //转账接口请求地址
    private static final String payUrl="https://hfpay.testpnr.com/api/acou/trac01";
    //加签证书地址
    private static final String pfxFile="/app/etc/product/888888-NEW.pfx";
    //加签证书秘钥
    private static final String pfxFilePwd="123456";
    //解签证书地址
    private static final String cerFile="/app/etc/product/CFCA_ACS_TEST_OCA31.cer";
    //解签证书所属商户号
    private static final String hfMerId="100001";

    /**
     * 转账
     * @param map
     * @param request
     * @param response
     * @param session
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/trac01")
    @ResponseBody
    public String bind(ModelMap map, HttpServletRequest request,
                      HttpServletResponse response, HttpSession session) throws Exception {
        //组装支付+请求参数
        Map<String, String> payParams = new HashMap<String, String>();
        payParams.put(Constants.VERSION, Constants.VERSION_VALUE);
        payParams.put(Constants.MER_CUST_ID, merCustId);
        payParams.put(Constants.ORDER_ID, makeOrderId());
        SimpleDateFormat dateformat = new SimpleDateFormat("yyyyMMdd");
        String dateStr = dateformat.format(System.currentTimeMillis());
        payParams.put(Constants.ORDER_DATE, dateStr);

        payParams.put(Constants.OUT_ACCT_ID, "5125235");
        payParams.put(Constants.OUT_CUST_ID, outCustId);
        payParams.put(Constants.IN_CUST_ID, inCustId);
        payParams.put(Constants.IN_ACCT_ID, "12341414");
        payParams.put(Constants.TRANSFER_AMT, "12341414");
        payParams.put(Constants.MER_PRIV, "");
        payParams.put(Constants.EXTENSION, "");

        CfcaInfoBo cfcaInfoBo = new CfcaInfoBo();
        // 解签证书
        cfcaInfoBo.setCerFile(cerFile);
        // 加签证书
        cfcaInfoBo.setPfxFile(pfxFile);
        // 加签密码
        cfcaInfoBo.setPfxFilePwd(pfxFilePwd);
        // 商户ID
        cfcaInfoBo.setNpayMerId(hfMerId);

        // 转换成json格式
        String paramsStr = JSON.toJSONString(payParams);
        log.info("转账请求参数："+paramsStr);
        // 加签
        String sign = SecurityService.sign(paramsStr,cfcaInfoBo);
        HttpRequest httpRequest = HttpRequest.post(payUrl).charset("UTF-8");
        // 组织post数据
        String postStr = "version=" + Constants.VERSION_VALUE
                + "&mer_cust_id=" + merCustId
                + "&check_value=" + sign;

        // 发送请求给汇付
        HttpResponse httpResponse = httpRequest
                .contentType("application/x-www-form-urlencoded").body(postStr)
                .send();
        // 取得同步返回数据
        String body = httpResponse.bodyText();
        // 进行验签
        String resultStr = SecurityService.parseCVResult(body,cfcaInfoBo);
        log.info("转账返回参数："+resultStr);
        return resultStr;
    }

    /**
     * 生成订单号
     * @return
     */
    private String makeOrderId(){
        return "TEST"+System.currentTimeMillis();
    }
}
