package com.huifu.example.file;

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import jodd.http.HttpRequest;
import jodd.http.HttpResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.huifu.hfpay.master.domain.CfcaInfoBo;
import com.huifu.hfpay.master.util.constant.Constants;
import com.huifu.hfpay.master.util.security.SecurityService;

/**
 * 下载文件
 * @author yinfeng.yuan
 */
@Controller
@RequestMapping(value = "/")
public class File02 {
	public static Logger log = LoggerFactory.getLogger(File02.class);

	//商户客户号
	private static final String merCustId="6666000000114846";
	//文件下载请求地址
	private static final String fileUrl="https://hfpay.testpnr.com/api/alse/file02";
	//加签证书地址
	private static final String pfxFile="/app/etc/product/888888-NEW.pfx";
	//加签证书秘钥
	private static final String pfxFilePwd="123456";
	//解签证书地址
	private static final String cerFile="/app/etc/product/CFCA_ACS_TEST_OCA31.cer";
	//解签证书所属商户号
	private static final String hfMerId="100001";
	@RequestMapping(value = "/file02")
	@ResponseBody
	public String pay(ModelMap map, HttpServletRequest request,
			HttpServletResponse response, HttpSession session) throws Exception {
		log.info("************文件查询请求**************");
					
		//组装请求参数
		Map<String, String> payParams = new HashMap<String, String>();
		payParams.put(Constants.VERSION, Constants.VERSION_VALUE);	
		payParams.put(Constants.MER_CUST_ID, merCustId);
		payParams.put(Constants.FILE_DATE,"20190805");
		payParams.put(Constants.FILE_TYPE, "1");
		//加解签证书参数
		CfcaInfoBo cfcaInfoBo = new CfcaInfoBo();
		// 解签证书
		// 解签证书
		cfcaInfoBo.setCerFile(cerFile);
		// 加签证书
		cfcaInfoBo.setPfxFile(pfxFile);
		// 加签密码
		cfcaInfoBo.setPfxFilePwd(pfxFilePwd);
		//商户ID
		cfcaInfoBo.setNpayMerId(hfMerId);
		
		// 转换成json格式
		String paramsStr = JSON.toJSONString(payParams);
		log.info("文件下载请求参数："+paramsStr);
		// 加签
		String sign = SecurityService.sign(paramsStr,cfcaInfoBo);
		HttpRequest httpRequest = HttpRequest.post(fileUrl).charset("UTF-8");
		// 组织post数据
		String postStr = "version=" + Constants.VERSION_VALUE
				+ "&mer_cust_id=" + merCustId 
				+ "&check_value=" + sign;

		// 发送请求给汇付
		HttpResponse httpResponse = httpRequest
				.contentType("application/x-www-form-urlencoded").body(postStr)
				.send();
		// 取得同步返回数据
		String body = httpResponse.bodyText();
		// 进行验签
		String resultStr = SecurityService.parseCVResult(body,cfcaInfoBo);
		
		JSONObject json = JSONObject.parseObject(resultStr);
		String fileInfos = getValue(json.get("file_infos"));
		
		//状态成功时，继续处理
		if("C00000".equals(json.get("resp_code"))){
			List<FileInfo> fileInfoList = (List<FileInfo>) JSONArray.parseArray(fileInfos, FileInfo.class);
			
			if(fileInfoList != null && fileInfoList.size() >0 ){
				for(FileInfo item : fileInfoList){
					//下载文件
					saveUrlAs("/app/demo/",item);
				}
			}
		}
		
		
		log.info("文件下载返回参数："+resultStr);
		return resultStr;
	}
	
	
	/**
	 * 报错下载文件
	 * @param savePath 保存路径
	 * @param fileInfo 文件基本信息
	 */
	private static void saveUrlAs(String savePath,FileInfo fileInfo){  
	    //创建不同的文件夹目录  
	    File file=new File(savePath);  
	    //判断文件夹是否存在  
	    if (!file.exists()){  
	        //如果文件夹不存在，则创建新的的文件夹  
	        file.mkdirs();  
	    }  
	    FileOutputStream fileOut = null;  
	    HttpURLConnection conn = null;  
	    InputStream inputStream = null;  
	    try{  
	        // 建立链接  
	        URL httpUrl=new URL(fileInfo.getFileUrl());  
	        conn=(HttpURLConnection) httpUrl.openConnection();  
	        //以Post方式提交表单，默认get方式  
	        conn.setRequestMethod("GET");  
	        conn.setDoInput(true);    
	        conn.setDoOutput(true);  
	        // post方式不能使用缓存   
	        conn.setUseCaches(false);  
	        //连接指定的资源   
	        conn.connect();  
	        //获取网络输入流  
	        inputStream=conn.getInputStream();  
	        BufferedInputStream bis = new BufferedInputStream(inputStream);  
	        //判断文件的保存路径后面是否以/结尾  
	        if(!savePath.endsWith("/")) {  
	            savePath += "/";  
	        }  
	        //写入到文件（注意文件保存路径的后面一定要加上文件的名称）  
	        fileOut = new FileOutputStream(savePath+fileInfo.getFileName());  
	        BufferedOutputStream bos = new BufferedOutputStream(fileOut);  
	           
	        byte[] buf = new byte[4096];  
	        int length = bis.read(buf);  
	        //保存文件  
	        while(length != -1){  
	            bos.write(buf, 0, length);  
	            length = bis.read(buf);  
	        }  
	        bos.close();  
	        bis.close();  
	        conn.disconnect();  
	    } catch (Exception e){  
	    	log.error("文件下载异常",e);
	    }  
	       
	    return;  
	       
	}

    private String getValue(Object obj){
    	if(obj == null){
    		return "";
    	}else{
    		return obj.toString();
    	}
    }

	
}
