package com.huifu.example.hfpay;

import com.alibaba.fastjson.JSON;
import com.huifu.hfpay.master.domain.CfcaInfoBo;
import com.huifu.hfpay.master.util.constant.Constants;
import com.huifu.hfpay.master.util.security.SecurityService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.Map;

/**
 * 快捷支付页面版，调用支付过程中有汇付页面
 * 
 * @author yinfeng.yuan
 *
 */
@Controller
@RequestMapping(value = "/")
public class Pay010 {

	public static Logger log = LoggerFactory.getLogger(Pay010.class);

	//商户客户号
	private static final String merCustId="6666000000002619";
	//收款方用户客户号
	private static final String inCustId="6666000000002619";
	//收款方子账户
	private static final String inAcctId="2744";
	//快捷支付请求地址
	private static final String qpUrl="https://hfpay.testpnr.com/api/hfpay/pay010";
	//加签证书地址
	private static final String pfxFile="/app/etc/product/888888-NEW.pfx";
	//加签证书秘钥
	private static final String pfxFilePwd="123456";
	//解签证书地址
	private static final String cerFile="/app/etc/product/CFCA_ACS_TEST_OCA31.cer";
	//解签证书所属商户号
	private static final String hfMerId="100001";
	/**
	 * 请求快捷请求参数，并跳转到页面
	 * @param map
	 * @param request
	 * @param response
	 * @param session
	 * @return
	 * @throws Exception
	 */
	@RequestMapping(value = "/pay010")
	public String pay(ModelMap map, HttpServletRequest request,
			HttpServletResponse response, HttpSession session) throws Exception {
		//组装支付+请求参数
		Map<String, String> payParams = new HashMap<String, String>();
		payParams.put(Constants.VERSION, Constants.VERSION_VALUE);	
		payParams.put(Constants.MER_CUST_ID, merCustId);
		payParams.put(Constants.ORDER_ID, makeOrderId());
		SimpleDateFormat dateformat = new SimpleDateFormat("yyyyMMdd");
		String dateStr = dateformat.format(System.currentTimeMillis());
		payParams.put(Constants.ORDER_DATE, dateStr);
		payParams.put(Constants.IN_CUST_ID, inCustId);
		payParams.put(Constants.IN_ACCT_ID, inAcctId);
		payParams.put(Constants.TRANS_AMT, "0.01");
		payParams.put(Constants.BIZ_TRANS_TYPE, "P");		
		payParams.put(Constants.DEV_INFO_JSON, "{'ipAddr':'10.99.195.11','devType':'1'}");
		//如果需要支付完成后跳转指定页面，则需要设置此项
		//payParams.put(Constants.RET_URL,"http://172.31.18.80:8089/service-demo/quickPay/demo/ret");
		payParams.put(Constants.MER_PRIV, "");
		payParams.put(Constants.EXTENSION, "");
		
		CfcaInfoBo cfcaInfoBo = new CfcaInfoBo();
		// 解签证书
		cfcaInfoBo.setCerFile(cerFile);
		// 加签证书
		cfcaInfoBo.setPfxFile(pfxFile);
		// 加签密码
		cfcaInfoBo.setPfxFilePwd(pfxFilePwd);
		// 商户ID
		cfcaInfoBo.setNpayMerId(hfMerId);
		
		// 转换成json格式
		String paramsStr = JSON.toJSONString(payParams);
		log.info("快捷支付请求参数："+paramsStr);
		// 加签
		String sign = SecurityService.sign(paramsStr,cfcaInfoBo);
		
		map.put("version", Constants.VERSION_VALUE);
		map.put("merCustId", merCustId);
		//设置加签后的接口参数
		map.put("sign", sign);
		//设置接口地址
		map.put("url", qpUrl);

		return "submit";
	}
	
	/**
	 * 生成订单号
	 * @return
	 */
	private String makeOrderId(){
		return "TEST"+System.currentTimeMillis();
	}

	
}
