package com.huifu.example.hfpay;

import com.alibaba.fastjson.JSON;
import com.huifu.hfpay.master.domain.CfcaInfoBo;
import com.huifu.hfpay.master.util.constant.Constants;
import com.huifu.hfpay.master.util.security.SecurityService;
import jodd.http.HttpRequest;
import jodd.http.HttpResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.Map;

/**
 * 后台方式获取支付凭证信息 调用支付过程中没有汇付页面 此接口与支持微信支付、支付宝统一下单支付 支付宝APP支付和applePay支付暂时不支持
 * 
 * @author yinfeng.yuan
 */
@Controller
@RequestMapping(value = "/")
public class Pay012 {
	public static Logger log = LoggerFactory.getLogger(Pay012.class);

	//商户客户号
	private static final String merCustId="6666000000114846";
	//收款方用户客户号
	private static final String inCustId="6666000000114846";
	//收款方子账户
	private static final String inAcctId="135740";
	//微信支付宝支付请求地址
	private static final String qrcpUrl="https://hfpay.testpnr.com/api/hfpay/pay012";
	//加签证书地址
	private static final String pfxFile="/app/etc/product/888888-NEW.pfx";
	//加签证书秘钥
	private static final String pfxFilePwd="123456";
	//解签证书地址
	private static final String cerFile="/app/etc/product/CFCA_ACS_TEST_OCA31.cer";
	//解签证书所属商户号
	private static final String hfMerId="100001";
	
	@RequestMapping(value = "/pay012")
	@ResponseBody
	public String pay(ModelMap map, HttpServletRequest request,
			HttpServletResponse response, HttpSession session) throws Exception {
		log.info("************app支付请求**************");
					
		//组装请求参数
		Map<String, String> payParams = new HashMap<String, String>();
		payParams.put(Constants.VERSION, Constants.VERSION_VALUE);	
		payParams.put(Constants.MER_CUST_ID, merCustId);
		payParams.put(Constants.ORDER_ID, makeOrderId());
		SimpleDateFormat dateformat = new SimpleDateFormat("yyyyMMdd");
		String dateStr = dateformat.format(System.currentTimeMillis());
		payParams.put(Constants.ORDER_DATE, dateStr);
		payParams.put(Constants.IN_CUST_ID, inCustId);
		payParams.put(Constants.IN_ACCT_ID, inAcctId);
		//支付宝正扫
		payParams.put(Constants.APP_PAY_TYPE, "02");
		payParams.put(Constants.TRANS_AMT, "10.01");		
		payParams.put(Constants.BIZ_TRANS_TYPE, "P");		
		payParams.put(Constants.DEV_INFO_JSON, "{'ipAddr':'10.99.195.11','devType':'1'}");
		payParams.put(Constants.GOODS_DESC, "测试用");
		payParams.put(Constants.MER_PRIV, "");
		//加解签证书参数
		CfcaInfoBo cfcaInfoBo = new CfcaInfoBo();
		// 解签证书
		// 解签证书
		cfcaInfoBo.setCerFile(cerFile);
		// 加签证书
		cfcaInfoBo.setPfxFile(pfxFile);
		// 加签密码
		cfcaInfoBo.setPfxFilePwd(pfxFilePwd);
		//商户ID
		cfcaInfoBo.setNpayMerId(hfMerId);
		
		// 转换成json格式
		String paramsStr = JSON.toJSONString(payParams);
		log.info("app支付请求参数："+paramsStr);
		// 加签
		String sign = SecurityService.sign(paramsStr,cfcaInfoBo);
		HttpRequest httpRequest = HttpRequest.post(qrcpUrl).charset("UTF-8");
		// 组织post数据
		String postStr = "version=" + Constants.VERSION_VALUE
				+ "&mer_cust_id=" + merCustId 
				+ "&check_value=" + sign;

		// 发送请求给汇付
		HttpResponse httpResponse = httpRequest
				.contentType("application/x-www-form-urlencoded").body(postStr)
				.send();
		// 取得同步返回数据
		String body = httpResponse.bodyText();
		// 进行验签
		String resultStr = SecurityService.parseCVResult(body,cfcaInfoBo);
		log.info("app支付返回参数："+resultStr);
		return resultStr;
	}
	/**
	 * 生成订单号
	 * @return
	 */
	private String makeOrderId(){
		return "TEST"+System.currentTimeMillis();
	}
	
}
