package com.huifu.example.transQuery;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import jodd.http.HttpRequest;
import jodd.http.HttpResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.alibaba.fastjson.JSON;
import com.huifu.hfpay.master.domain.CfcaInfoBo;
import com.huifu.hfpay.master.util.constant.Constants;
import com.huifu.hfpay.master.util.security.SecurityService;


/**
 * 后台方式执行退款
 * 调用退款过程中没有汇付页面
 * @author yinfeng.yuan
 */
@Controller
@RequestMapping(value="/")
public class Qrp008 {
	public static Logger log = LoggerFactory.getLogger(Qrp008.class);

	//商户客户号
	private static final String merCustId="6666000000002619";
	//微信支付宝支付请求地址
	private static final String queryUrl="https://hfpay.testpnr.com/api/alse/qrp008";
	//加签证书地址
	private static final String pfxFile="/app/etc/product/888888-NEW.pfx";
	//加签证书秘钥
	private static final String pfxFilePwd="123456";
	//解签证书地址
	private static final String cerFile="/app/etc/product/CFCA_ACS_TEST_OCA31.cer";
	//解签证书所属商户号
	private static final String hfMerId="100001";
	
	@RequestMapping("/qrp008")
	@ResponseBody
	public String query(ModelMap map, HttpServletRequest request, HttpServletResponse response,
            HttpSession session) throws Exception {
		
        // 请求数据map格式
        Map<String, String> payParams = new HashMap<String, String>();
        
        // 根据接口规范，传入请求数据
        payParams.put(Constants.VERSION, Constants.VERSION_VALUE);
        payParams.put(Constants.MER_CUST_ID,merCustId);
        payParams.put(Constants.ORDER_ID,"2019080421261695929");
        payParams.put(Constants.ORDER_DATE,"20190801");
        payParams.put(Constants.TRANS_TYPE,"4");
        payParams.put(Constants.MER_PRIV, "");
        payParams.put(Constants.EXTENSION, "");
        
        CfcaInfoBo cfcaInfoBo = new CfcaInfoBo();
        // 解签证书
 		cfcaInfoBo.setCerFile(cerFile);
 		// 加签证书
 		cfcaInfoBo.setPfxFile(pfxFile);
 		// 加签密码
 		cfcaInfoBo.setPfxFilePwd(pfxFilePwd);
 		//商户ID
 		cfcaInfoBo.setNpayMerId(hfMerId);
 	    // 转换成json格式
		String paramsStr = JSON.toJSONString(payParams);
		
		log.info("状态查询请求参数：" + paramsStr);

		// 进行加签
		String sign = SecurityService.sign(paramsStr,cfcaInfoBo);

		HttpRequest httpRequest = HttpRequest.post(queryUrl).charset("UTF-8");

		// 组织post数据
		String postStr ="version=" + Constants.VERSION_VALUE
				+ "&mer_cust_id=" + merCustId 
				+ "&check_value=" + sign;

		// 发送请求给汇付
		HttpResponse httpResponse = httpRequest
				.contentType("application/x-www-form-urlencoded").body(postStr)
				.send();
		// 取得同步返回数据
		String body = httpResponse.bodyText();
		// 进行验签
		String resultStr =  SecurityService.parseCVResult(body,cfcaInfoBo);
		log.info("状态查询返回参数：" + resultStr);
        return resultStr;
    }
	
	
}
